==> groovy-cps-1.9-sources.jar: com/cloudbees/groovy/cps/CpsTransformer.java <==
package com.cloudbees.groovy.cps;

import org.codehaus.groovy.ast.*;
import org.codehaus.groovy.ast.expr.*;
import org.codehaus.groovy.ast.stmt.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class CpsTransformer
  extends org.codehaus.groovy.control.customizers.CompilationCustomizer  implements
    org.codehaus.groovy.ast.GroovyCodeVisitor,    groovy.lang.GroovyObject {
protected groovy.lang.Closure parent;
public CpsTransformer
() {
super ((org.codehaus.groovy.control.CompilePhase)null);
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  void setConfiguration(TransformerConfiguration config) { }
@java.lang.Override() public  void call(org.codehaus.groovy.control.SourceUnit source, org.codehaus.groovy.classgen.GeneratorContext context, org.codehaus.groovy.ast.ClassNode classNode) { }
protected  boolean shouldBeTransformed(org.codehaus.groovy.ast.MethodNode node) { return false;}
public  void visitMethod(org.codehaus.groovy.ast.MethodNode m) { }
protected  org.codehaus.groovy.ast.expr.Expression makeBuilder(org.codehaus.groovy.ast.MethodNode m) { return (org.codehaus.groovy.ast.expr.Expression)null;}
protected  java.lang.Class getTrustTag() { return (java.lang.Class)null;}
protected  void visitNontransformedMethod(org.codehaus.groovy.ast.MethodNode m) { }
protected  void visit(org.codehaus.groovy.ast.ASTNode e) { }
protected  void visit(java.util.Collection<? extends org.codehaus.groovy.ast.ASTNode> col) { }
protected  void makeNode(java.lang.String methodName, java.lang.Object args) { }
protected  void makeNode(org.codehaus.groovy.ast.ClassNode type, java.lang.Object args) { }
protected  org.codehaus.groovy.ast.expr.TupleExpression makeChildren(java.lang.Object args) { return (org.codehaus.groovy.ast.expr.TupleExpression)null;}
protected  void makeNode(java.lang.String methodName) { }
protected  void loc(org.codehaus.groovy.ast.ASTNode e) { }
protected  void literal(java.lang.String s) { }
protected  void literal(org.codehaus.groovy.ast.ClassNode c) { }
protected  void literal(int n) { }
protected  void literal(boolean b) { }
public  void visitEmptyExpression(org.codehaus.groovy.ast.expr.EmptyExpression e) { }
public  void visitEmptyStatement(org.codehaus.groovy.ast.stmt.EmptyStatement e) { }
public  void visitMethodCallExpression(org.codehaus.groovy.ast.expr.MethodCallExpression call) { }
public  void visitBlockStatement(org.codehaus.groovy.ast.stmt.BlockStatement b) { }
public  void visitForLoop(org.codehaus.groovy.ast.stmt.ForStatement forLoop) { }
public  void visitWhileLoop(org.codehaus.groovy.ast.stmt.WhileStatement loop) { }
public  void visitDoWhileLoop(org.codehaus.groovy.ast.stmt.DoWhileStatement loop) { }
public  void visitIfElse(org.codehaus.groovy.ast.stmt.IfStatement stmt) { }
public  void visitExpressionStatement(org.codehaus.groovy.ast.stmt.ExpressionStatement statement) { }
public  void visitReturnStatement(org.codehaus.groovy.ast.stmt.ReturnStatement statement) { }
public  void visitAssertStatement(org.codehaus.groovy.ast.stmt.AssertStatement statement) { }
public  void visitTryCatchFinally(org.codehaus.groovy.ast.stmt.TryCatchStatement stmt) { }
public  void visitSwitch(org.codehaus.groovy.ast.stmt.SwitchStatement stmt) { }
public  void visitCaseStatement(org.codehaus.groovy.ast.stmt.CaseStatement stmt) { }
public  void visitBreakStatement(org.codehaus.groovy.ast.stmt.BreakStatement statement) { }
public  void visitContinueStatement(org.codehaus.groovy.ast.stmt.ContinueStatement statement) { }
public  void visitThrowStatement(org.codehaus.groovy.ast.stmt.ThrowStatement st) { }
public  void visitSynchronizedStatement(org.codehaus.groovy.ast.stmt.SynchronizedStatement statement) { }
public  void visitCatchStatement(org.codehaus.groovy.ast.stmt.CatchStatement stmt) { }
public  void visitStaticMethodCallExpression(org.codehaus.groovy.ast.expr.StaticMethodCallExpression exp) { }
public  void visitConstructorCallExpression(org.codehaus.groovy.ast.expr.ConstructorCallExpression call) { }
public  void visitTernaryExpression(org.codehaus.groovy.ast.expr.TernaryExpression exp) { }
public  void visitShortTernaryExpression(org.codehaus.groovy.ast.expr.ElvisOperatorExpression exp) { }
public  void visitBinaryExpression(org.codehaus.groovy.ast.expr.BinaryExpression exp) { }
public  void visitPrefixExpression(org.codehaus.groovy.ast.expr.PrefixExpression exp) { }
public  void visitPostfixExpression(org.codehaus.groovy.ast.expr.PostfixExpression exp) { }
protected  java.lang.String prepostfixOperatorSuffix(org.codehaus.groovy.ast.expr.Expression exp) { return (java.lang.String)null;}
public  void visitBooleanExpression(org.codehaus.groovy.ast.expr.BooleanExpression exp) { }
public  void visitClosureExpression(org.codehaus.groovy.ast.expr.ClosureExpression exp) { }
public  void visitTupleExpression(org.codehaus.groovy.ast.expr.TupleExpression expression) { }
public  void visitMapExpression(org.codehaus.groovy.ast.expr.MapExpression exp) { }
public  void visitMapEntryExpression(org.codehaus.groovy.ast.expr.MapEntryExpression expression) { }
public  void visitListExpression(org.codehaus.groovy.ast.expr.ListExpression exp) { }
public  void visitRangeExpression(org.codehaus.groovy.ast.expr.RangeExpression exp) { }
public  void visitPropertyExpression(org.codehaus.groovy.ast.expr.PropertyExpression exp) { }
public  void visitAttributeExpression(org.codehaus.groovy.ast.expr.AttributeExpression exp) { }
public  void visitFieldExpression(org.codehaus.groovy.ast.expr.FieldExpression exp) { }
public  void visitMethodPointerExpression(org.codehaus.groovy.ast.expr.MethodPointerExpression exp) { }
public  void visitConstantExpression(org.codehaus.groovy.ast.expr.ConstantExpression expression) { }
public  void visitClassExpression(org.codehaus.groovy.ast.expr.ClassExpression expression) { }
public  void visitVariableExpression(org.codehaus.groovy.ast.expr.VariableExpression exp) { }
public  void visitDeclarationExpression(org.codehaus.groovy.ast.expr.DeclarationExpression exp) { }
public  void visitGStringExpression(org.codehaus.groovy.ast.expr.GStringExpression exp) { }
public  void visitArrayExpression(org.codehaus.groovy.ast.expr.ArrayExpression exp) { }
public  void visitSpreadExpression(org.codehaus.groovy.ast.expr.SpreadExpression expression) { }
public  void visitSpreadMapExpression(org.codehaus.groovy.ast.expr.SpreadMapExpression expression) { }
public  void visitNotExpression(org.codehaus.groovy.ast.expr.NotExpression exp) { }
public  void visitUnaryMinusExpression(org.codehaus.groovy.ast.expr.UnaryMinusExpression exp) { }
public  void visitUnaryPlusExpression(org.codehaus.groovy.ast.expr.UnaryPlusExpression exp) { }
public  void visitBitwiseNegationExpression(org.codehaus.groovy.ast.expr.BitwiseNegationExpression exp) { }
public  void visitCastExpression(org.codehaus.groovy.ast.expr.CastExpression exp) { }
public  void visitArgumentlistExpression(org.codehaus.groovy.ast.expr.ArgumentListExpression expression) { }
public  void visitClosureListExpression(org.codehaus.groovy.ast.expr.ClosureListExpression closureListExpression) { }
public  void visitBytecodeExpression(org.codehaus.groovy.classgen.BytecodeExpression expression) { }
}

==> groovy-cps-1.10-sources.jar: com/cloudbees/groovy/cps/CpsTransformer.java <==
package com.cloudbees.groovy.cps;

import org.codehaus.groovy.ast.*;
import org.codehaus.groovy.ast.expr.*;
import org.codehaus.groovy.ast.stmt.*;
import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class CpsTransformer
  extends org.codehaus.groovy.control.customizers.CompilationCustomizer  implements
    org.codehaus.groovy.ast.GroovyCodeVisitor,    groovy.lang.GroovyObject {
protected TransformerConfiguration config;
protected groovy.lang.Closure parent;
public CpsTransformer
() {
super ((org.codehaus.groovy.control.CompilePhase)null);
}
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  void setConfiguration(TransformerConfiguration config) { }
@java.lang.Override() public  void call(org.codehaus.groovy.control.SourceUnit source, org.codehaus.groovy.classgen.GeneratorContext context, org.codehaus.groovy.ast.ClassNode classNode) { }
protected  boolean shouldBeTransformed(org.codehaus.groovy.ast.MethodNode node) { return false;}
public  void visitMethod(org.codehaus.groovy.ast.MethodNode m) { }
protected  org.codehaus.groovy.ast.expr.Expression makeBuilder(org.codehaus.groovy.ast.MethodNode m) { return (org.codehaus.groovy.ast.expr.Expression)null;}
protected  java.lang.Class getTrustTag() { return (java.lang.Class)null;}
protected  void visitNontransformedMethod(org.codehaus.groovy.ast.MethodNode m) { }
protected  void visit(org.codehaus.groovy.ast.ASTNode e) { }
protected  void visit(java.util.Collection<? extends org.codehaus.groovy.ast.ASTNode> col) { }
protected  void visitWithSafepoint(org.codehaus.groovy.ast.stmt.Statement st) { }
protected  void makeNode(java.lang.String methodName, java.lang.Object args) { }
protected  void makeNode(org.codehaus.groovy.ast.ClassNode type, java.lang.Object args) { }
protected  org.codehaus.groovy.ast.expr.TupleExpression makeChildren(java.lang.Object args) { return (org.codehaus.groovy.ast.expr.TupleExpression)null;}
protected  void makeNode(java.lang.String methodName) { }
protected  void loc(org.codehaus.groovy.ast.ASTNode e) { }
protected  void literal(java.lang.String s) { }
protected  void literal(org.codehaus.groovy.ast.ClassNode c) { }
protected  void literal(int n) { }
protected  void literal(boolean b) { }
public  void visitEmptyExpression(org.codehaus.groovy.ast.expr.EmptyExpression e) { }
public  void visitEmptyStatement(org.codehaus.groovy.ast.stmt.EmptyStatement e) { }
public  void visitMethodCallExpression(org.codehaus.groovy.ast.expr.MethodCallExpression call) { }
public  void visitBlockStatement(org.codehaus.groovy.ast.stmt.BlockStatement b) { }
public  void visitForLoop(org.codehaus.groovy.ast.stmt.ForStatement forLoop) { }
public  void visitWhileLoop(org.codehaus.groovy.ast.stmt.WhileStatement loop) { }
public  void visitDoWhileLoop(org.codehaus.groovy.ast.stmt.DoWhileStatement loop) { }
public  void visitIfElse(org.codehaus.groovy.ast.stmt.IfStatement stmt) { }
public  void visitExpressionStatement(org.codehaus.groovy.ast.stmt.ExpressionStatement statement) { }
public  void visitReturnStatement(org.codehaus.groovy.ast.stmt.ReturnStatement statement) { }
public  void visitAssertStatement(org.codehaus.groovy.ast.stmt.AssertStatement statement) { }
public  void visitTryCatchFinally(org.codehaus.groovy.ast.stmt.TryCatchStatement stmt) { }
public  void visitSwitch(org.codehaus.groovy.ast.stmt.SwitchStatement stmt) { }
public  void visitCaseStatement(org.codehaus.groovy.ast.stmt.CaseStatement stmt) { }
public  void visitBreakStatement(org.codehaus.groovy.ast.stmt.BreakStatement statement) { }
public  void visitContinueStatement(org.codehaus.groovy.ast.stmt.ContinueStatement statement) { }
public  void visitThrowStatement(org.codehaus.groovy.ast.stmt.ThrowStatement st) { }
public  void visitSynchronizedStatement(org.codehaus.groovy.ast.stmt.SynchronizedStatement statement) { }
public  void visitCatchStatement(org.codehaus.groovy.ast.stmt.CatchStatement stmt) { }
public  void visitStaticMethodCallExpression(org.codehaus.groovy.ast.expr.StaticMethodCallExpression exp) { }
public  void visitConstructorCallExpression(org.codehaus.groovy.ast.expr.ConstructorCallExpression call) { }
public  void visitTernaryExpression(org.codehaus.groovy.ast.expr.TernaryExpression exp) { }
public  void visitShortTernaryExpression(org.codehaus.groovy.ast.expr.ElvisOperatorExpression exp) { }
public  void visitBinaryExpression(org.codehaus.groovy.ast.expr.BinaryExpression exp) { }
public  void visitPrefixExpression(org.codehaus.groovy.ast.expr.PrefixExpression exp) { }
public  void visitPostfixExpression(org.codehaus.groovy.ast.expr.PostfixExpression exp) { }
protected  java.lang.String prepostfixOperatorSuffix(org.codehaus.groovy.ast.expr.Expression exp) { return (java.lang.String)null;}
public  void visitBooleanExpression(org.codehaus.groovy.ast.expr.BooleanExpression exp) { }
public  void visitClosureExpression(org.codehaus.groovy.ast.expr.ClosureExpression exp) { }
public  void visitTupleExpression(org.codehaus.groovy.ast.expr.TupleExpression expression) { }
public  void visitMapExpression(org.codehaus.groovy.ast.expr.MapExpression exp) { }
public  void visitMapEntryExpression(org.codehaus.groovy.ast.expr.MapEntryExpression expression) { }
public  void visitListExpression(org.codehaus.groovy.ast.expr.ListExpression exp) { }
public  void visitRangeExpression(org.codehaus.groovy.ast.expr.RangeExpression exp) { }
public  void visitPropertyExpression(org.codehaus.groovy.ast.expr.PropertyExpression exp) { }
public  void visitAttributeExpression(org.codehaus.groovy.ast.expr.AttributeExpression exp) { }
public  void visitFieldExpression(org.codehaus.groovy.ast.expr.FieldExpression exp) { }
public  void visitMethodPointerExpression(org.codehaus.groovy.ast.expr.MethodPointerExpression exp) { }
public  void visitConstantExpression(org.codehaus.groovy.ast.expr.ConstantExpression expression) { }
public  void visitClassExpression(org.codehaus.groovy.ast.expr.ClassExpression expression) { }
public  void visitVariableExpression(org.codehaus.groovy.ast.expr.VariableExpression exp) { }
public  void visitDeclarationExpression(org.codehaus.groovy.ast.expr.DeclarationExpression exp) { }
public  void visitGStringExpression(org.codehaus.groovy.ast.expr.GStringExpression exp) { }
public  void visitArrayExpression(org.codehaus.groovy.ast.expr.ArrayExpression exp) { }
public  void visitSpreadExpression(org.codehaus.groovy.ast.expr.SpreadExpression expression) { }
public  void visitSpreadMapExpression(org.codehaus.groovy.ast.expr.SpreadMapExpression expression) { }
public  void visitNotExpression(org.codehaus.groovy.ast.expr.NotExpression exp) { }
public  void visitUnaryMinusExpression(org.codehaus.groovy.ast.expr.UnaryMinusExpression exp) { }
public  void visitUnaryPlusExpression(org.codehaus.groovy.ast.expr.UnaryPlusExpression exp) { }
public  void visitBitwiseNegationExpression(org.codehaus.groovy.ast.expr.BitwiseNegationExpression exp) { }
public  void visitCastExpression(org.codehaus.groovy.ast.expr.CastExpression exp) { }
public  void visitArgumentlistExpression(org.codehaus.groovy.ast.expr.ArgumentListExpression expression) { }
public  void visitClosureListExpression(org.codehaus.groovy.ast.expr.ClosureListExpression closureListExpression) { }
public  void visitBytecodeExpression(org.codehaus.groovy.classgen.BytecodeExpression expression) { }
}
